SystemOrganization addCategory: #'CS528-Project'!

Object subclass: #PokerTable
	instanceVariableNames: 'id websockets lock server'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!PokerTable class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/6/2013 20:06'!
id: anIdentifier 
	^ PokerTable new id: anIdentifier.! !

!PokerTable methodsFor: 'websocket' stamp: 'BrianDentino 7/6/2013 21:49'!
broadcast: aMessage
	"Send message to all connected clients"
	lock critical: [ 
		websockets do: [  :each |
			[ each sendMessage: aMessage ]
				on: NetworkError
				do: [  :exception | 
					each log debug: [ exception printString, ' NetworkError in broadcast...ignoring' ] ] ] ]! !

!PokerTable methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/6/2013 18:50'!
id
	^id! !

!PokerTable methodsFor: 'accessing' stamp: 'BrianDentino 7/6/2013 20:18'!
id: anIdentifier 
	id := anIdentifier.
	server delegate map: id to: (ZnWebSocketDelegate map: id to: self).! !

!PokerTable methodsFor: 'initialize-release' stamp: 'BrianDentino 7/6/2013 20:18'!
initialize 
	server := ZnServer default.
	websockets := OrderedCollection new.
	lock := Mutex new.! !

!PokerTable methodsFor: 'protocol' stamp: 'BrianDentino 7/6/2013 21:36'!
register: clientWebSocket
	lock critical: [ 
		websockets add: clientWebSocket ].! !

!PokerTable methodsFor: 'protocol' stamp: 'BrianDentino 7/6/2013 22:30'!
unregister: clientWebSocket
	lock critical: [ 
		websockets remove: clientWebSocket ifAbsent: [ ] ] .! !

!PokerTable methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/6/2013 22:54'!
value: websocket

	[ self register: websocket.
		websocket runWith: [ :message |
			websocket log info: [ 'Server received message: ', message printString ].
			self broadcast: message ] ]
	on: ConnectionClosed 
	do: [ 
		websocket log debug: 'Connection close, cleaning up'.
		self unregister: websocket ].! !

ZnWebSocket subclass: #TableWebsocket
	instanceVariableNames: 'tableID delegate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!TableWebsocket class methodsFor: 'initialize' stamp: 'BrianDentino 7/6/2013 22:39'!
tableID: id delegate: aDelegate 
	^ ((TableWebsocket to: 'ws://localhost:', ZnServer default port, '/', id) tableID: id) delegate: aDelegate.! !

!TableWebsocket methodsFor: 'initialize-release' stamp: 'BrianDentino 7/6/2013 22:57'!
delegate: aDelegate
	delegate := aDelegate.
	[self runWith: [ :message |
      	self crLog: 'Client received message: ', message printString. 
		delegate onMessage: message].] fork.! !

!TableWebsocket methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/6/2013 22:21'!
initialize
	super initialize.
	self role: #client.! !

!TableWebsocket methodsFor: 'initialize-release' stamp: 'BrianDentino 7/6/2013 22:24'!
tableID: id
	tableID := id! !

WAComponent subclass: #PokerPlayer
	instanceVariableNames: 'tableID tableConnection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!PokerPlayer class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/6/2013 22:38'!
tableID: id
	^(self new tableID: id)! !

!PokerPlayer methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/6/2013 21:18'!
initialize 
	super initialize.! !

!PokerPlayer methodsFor: 'accessing' stamp: 'BrianDentino 7/7/2013 01:25'!
onMessage: aMessage
	self halt.
	self call: TestComponent new.! !

!PokerPlayer methodsFor: 'accessing' stamp: 'BrianDentino 7/7/2013 01:29'!
renderContentOn: html
	html text: 'Welcome to table ', tableID.
	html horizontalRule.
	
	html form: [ 
		html submitButton
			callback: [self sayHello];
			with: 'Say Hello'. ].
		
	html anchor 
		callback: [ self onMessage: 'Message' ];
		with: 'Message'.
	
	html unorderedList 
		id: 'chatLog'.! !

!PokerPlayer methodsFor: 'accessing' stamp: 'BrianDentino 7/6/2013 22:30'!
sayHello
	tableConnection sendText: 'Hello!!'! !

!PokerPlayer methodsFor: 'accessing' stamp: 'BrianDentino 7/6/2013 21:29'!
tableID
	^tableID! !

!PokerPlayer methodsFor: 'accessing' stamp: 'BrianDentino 7/6/2013 22:39'!
tableID: id
	tableID := id.
	tableConnection := TableWebsocket tableID: id delegate: self.! !

WAComponent subclass: #PokerPlayerJS
	instanceVariableNames: 'tableID tableConnection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!PokerPlayerJS class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/7/2013 00:09'!
clientHtml
	^ '<!!DOCTYPE html>
<meta charset="utf-8" />
<title>WebSocket Chatroom</title>

<script language="javascript" type="text/javascript">

  var wsUri = "ws://" + location.host + "/ws-chatroom";
  var websocket;
  var output, handleInput, messageInput, sendButton, closeButton;

  function init() {
    output = document.getElementById("output");
    handleInput = document.getElementById("handleInput");
    messageInput = document.getElementById("messageInput");
    sendButton = document.getElementById("sendButton");
    closeButton = document.getElementById("closeButton");
    handleInput.value = "user-" + (new Date()).getMilliseconds();
    messageInput.onkeyup = function (evt) { if (evt.keyCode == 13) sendChatMessage(evt) }
    sendButton.onclick = function (evt) { sendChatMessage(evt) };
    closeButton.onclick = function (evt) { closeChat(evt) };
    testWebSocket();
  }

  function testWebSocket() {
    writeToScreen(wsUri);
    websocket = new WebSocket(wsUri);
    websocket.onopen = function(evt) { onOpen(evt) };
    websocket.onclose = function(evt) { onClose(evt) };
    websocket.onmessage = function(evt) { onMessage(evt) };
    websocket.onerror = function(evt) { onError(evt) };
  }

  function onOpen(evt) {
    writeToScreen("CONNECTED");
    doSend("Hi there !!");
  }

  function onClose(evt) {
    writeToScreen("DISCONNECTED");
  }

  function onMessage(evt) {
    writeToScreen(evt.data);
   }

  function onError(evt) {
    writeToScreen("<span style=''color: red''>ERROR:</span> " + evt.data);
  }

  function doSend(message) {
     websocket.send(handleInput.value + ">>" + message);
  }

  function writeToScreen(message) {
    var pre = document.createElement("p");
    pre.style.wordWrap = "break-word";
    pre.innerHTML = message;
    output.appendChild(pre);
  }

  function sendChatMessage(evt) {
    doSend(messageInput.value);
    messageInput.value = "";
  }

  function closeChat(evt) {
    doSend("Bye!!");
    websocket.close();
  }

  window.addEventListener("load", init, false);

</script>

<h2>WebSocket Chatroom</h2>
<div>
Handle: <input id="handleInput" type="text"/>
Message: <input id="messageInput" type="text" size="64"/> 
<input id="sendButton" type="submit" value="Send"/>
<input id="closeButton" type="submit" value="Close"/>
</div>
<div id="output"></div>

</html> '
! !

!PokerPlayerJS class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/7/2013 00:09'!
tableID: id
	^(self new tableID: id)! !

!PokerPlayerJS methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/7/2013 00:19'!
renderContentOn: html
	html text: 'Welcome to table ', tableID.
	html horizontalRule.
	
	html form: [ 
		html submitButton
			id: 'hello';
			with: 'Say Hello'. ].
	
	html unorderedList 
		id: 'chatLog'.
		
	self renderJavaScriptOn: html.! !

!PokerPlayerJS methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/7/2013 00:24'!
renderJavaScriptOn: html
	html script: '
var conn = {};
var log = document.getElementById("chatLog");
var helloButton = document.getElementById("hello");
var form = helloButton.form;
 
    conn = new WebSocket("ws://localhost:', (ZnServer default port), '/', tableID, '");
 
    conn.onmessage = function (event) {
      log.innerHTML = "<li>" + event.data + "</li>" + log.innerHTML;
    };
    
    conn.onclose = function (event) {
	console.log("connection closed")
    };

	form.addEventListener("submit", function (event) {
		event.preventDefault();
		if (conn.readyState === 1) {
			conn.send("Hello");      
		}
	}, false);
'! !

!PokerPlayerJS methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/7/2013 00:09'!
tableID: id
	tableID := id.
	! !

WAComponent subclass: #ProjectLanding
	instanceVariableNames: 'tables'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!ProjectLanding class methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/5/2013 22:42'!
canBeRoot
	^ true! !

!ProjectLanding class methodsFor: 'testing' stamp: 'BrianDentino 7/5/2013 23:26'!
initialize 
	"ProjectLanding initialize"
	
	WAAdmin register: self asApplicationAt: 'landing'! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/6/2013 21:23'!
createNewTable
	| id |
	id := self request: 'Enter a Table ID:'.
	tables at: id put: (PokerTable id: id).
	self joinTable: id.! !

!ProjectLanding methodsFor: 'initialization' stamp: 'BrianDentino 7/6/2013 20:22'!
initialize 
	super initialize.
	tables := Dictionary new.! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/6/2013 21:15'!
joinExistingTable
	| id |
	id := self requestTableID.
	self joinTable: id.
	! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/7/2013 09:58'!
joinTable: tableID
	self call: (PokerPlayerJS tableID: tableID).
	! !

!ProjectLanding methodsFor: 'rendering' stamp: 'BrianDentino 7/6/2013 21:27'!
renderContentOn: html
	html heading: 'Welcome to Smalltalk Casino!!'.
	html anchor
		callback: [ self createNewTable. ];
		with: 'Start a table'.
	html space.
	html anchor
		callback: [ self joinExistingTable. ];
		with: 'Join a table'.! !

!ProjectLanding methodsFor: 'setup' stamp: 'BrianDentino 7/6/2013 02:09'!
requestTableID
	| id |
	id := self request: 'Enter a Table ID:'.
	^id! !

!ProjectLanding methodsFor: 'as yet unclassified' stamp: 'BrianDentino 7/5/2013 22:46'!
states
	^ Array with: self.! !

WAComponent subclass: #TestComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CS528-Project'!

!TestComponent methodsFor: 'rendering' stamp: 'BrianDentino 7/6/2013 23:48'!
renderContentOn: html
	html render: 'Test'! !
ProjectLanding initialize!
